<?php
/**
 * $Horde: nic/graph.php,v 1.17 2007/01/02 00:41:47 jan Exp $
 *
 * Copyright 2002 Mike Cochrane <mike@graftonhall.co.nz>
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('NIC_BASE', dirname(__FILE__));
require_once NIC_BASE . '/lib/base.php';
require_once NIC_BASE . '/lib/Device.php';
require_once NIC_BASE . '/lib/Storage.php';
require_once 'Horde/Graph.php';

// Retrieve the form values.
$requestedid = Util::getFormData('deviceid');
$deviceid = Util::getFormData('device');
$graphID = Util::getFormData('graph');
$start_time = Util::getFormData('start', time() - 12 * 3600);
$end_time = Util::getFormData('end', time());
$step = Util::getFormData('step', 300);

// Get data values.
$dev = &Nic_Device::singleton($devices[$deviceid]['driver'], $devices[$deviceid]['params']);
$storage = &Nic_Storage::singleton();

$thisGraph = $dev->_graphs[$graphID];

$colors[0] = 'orange';
$colors[1] = 'blue';
$colors[2] = 'green';
$colors[3] = 'red';

// Create new graph.
$height = 250 + (50 * count($thisGraph['data']));
$graph = new Horde_Graph(array('width' => 600, 'height' => $height, 'temp' => Horde::getTempDir()));

// Set Graph Title
$graph->set('title', $thisGraph['title']);

$graph->set('xlabel', _("Time"));
$graph->set('ylabel', $thisGraph['axisLabel']);

$caption = '';
$labels = array();
$i = 0;
foreach ($thisGraph['data'] as $key => $plotdata) {
    $results = $storage->fetch($devices[$deviceid]['params']['hostname'],
                               $devices[$deviceid]['params']['subsystem'], $plotdata['source'], $plotdata['type'], $start_time, $end_time, $step);

    $values = array();
    $labels = array();
    foreach ($results as $label => $value) {
        $labels[] = date('H:i', $label);
        if (!empty($plotdata['scale_function'])) {
            switch ($plotdata['scale_function']) {
            case '*':
                $values[] = $value * $plotdata['scale_factor'];
                break;

            case '/':
                $values[] = $value / $plotdata['scale_factor'];
                break;
            }
        } else {
            $values[] = $value;
        }
    }

    // Add the line graph.
    $graph->addPlot('line', array('dataset' => $graph->addYData($values),
                                  'color' => $colors[$i++]));

    $caption .= (empty($caption) ? '' : "\n\n") .
        trim($plotdata['legend']) . "\n" . trim($plotdata['description']);
}

$graph->addXData($labels);

// Output the graph.
$graph->draw();
