<?php

require_once NIC_BASE . '/lib/Device/www.php';

/**
 * Nic_Device_apache:: is a Nic_Device implementation to retrieve data
 * from an Apache server via the server-status page.
 *
 * @author  Mike Cochrane <mike@graftonhall.co.nz>
 * @since   Nic 0.2
 * @package Nic
 */
class Nic_Device_apache extends Nic_Device_www {

    /* Array containing the details of graphs available for this device. */
    var $_graphs = array(
        array(
            'title' => 'Apache Usage',
            'axisLabel' => 'Hits / Second',
            'data' => array(
                array(
                    'source' => 'hits',
                    'legend' => 'Hits Per Second',
                    'description' => 'The number of pages requests per second being servered by this server.',
                    'type' => NIC_DATA_COUNTER,
                )
            )
        ),

        array(
            'title' => 'Apache Usage',
            'axisLabel' => 'KBs / Second',
            'data' => array(
                array(
                    'source' => 'traffic',
                    'legend' => 'Traffic',
                    'description' => 'The amount of traffic (in KBs) being sent by this server.',
                    'type' => NIC_DATA_COUNTER,
                )
            )
        ),

        array(
            'title' => 'Apache Usage',
            'axisLabel' => 'Requests / Second',
            'data' => array(
                array(
                    'source' => 'requestpersecond',
                    'legend' => 'Requests Per Second',
                    'description' => 'The number of requests for pages every second by clients of this server.',
                    'type' => NIC_DATA_RATE,
                )
            )
        ),

        array(
            'title' => 'Apache Usage',
            'axisLabel' => 'KB / Request',
            'data' => array(
                array(
                    'source' => 'bytesperrequest',
                    'legend' => 'KB Per Request',
                    'description' => 'The number of bytes sent out per request coming into this server.',
                    'type' => NIC_DATA_RATE,
                    'scale_function' => '/',
                    'scale_factor' => 1024,
                )
            )
        )
    );

    function Nic_Device_apache($params = array())
    {
        $this->params = $params;
    }

    function showDetails($templatePath, $device_id)
    {
        if (!$this->params['status']) {
            return;
        }

        if ($this->params['status'] === true) {
            $status = '/server-status';
        } else {
            $status = $this->params['status'];
        }

        $fcontents = @file('http://' . $this->params['hostspec'] . ':' . $this->params['port'] . $status);
        if (!is_array($fcontents)) {
            return;
        }

        include $templatePath . '/header.inc';

        foreach ($fcontents as $line) {
            if (strstr($line, 'Server Version') ||
                strstr($line, 'Server Built') ||
                strstr($line, 'Server uptime') ||
                strstr($line, 'Current Time') ||
                strstr($line, 'Restart Time')) {

                $value = explode(':', $line, 2);
                $description = $value[0];
                $value = $value[1];
                include $templatePath . '/row.inc';
            } elseif (strstr($line, 'Total accesses')) {
                /* Total Accesses */
                $values = explode(' - ', $line, 2);
                $value = explode(':', $values[0], 2);
                $description = $value[0];
                $value = $value[1];
                include $templatePath . '/row.inc';

                /* Total Traffic */
                $value = explode(':', $values[1], 2);
                $description = $value[0];
                $value = $value[1];
                include $templatePath . '/row.inc';
            } elseif (strstr($line, 'requests/sec')) {
                /* Requests / Second */
                $values = explode(' - ', $line, 3);
                $value = explode(' ', $values[0], 2);
                $description = $value[1];
                $value = $value[0];
                include $templatePath . '/row.inc';

                /* Bytes / Second */
                $value = explode(' ', $values[1], 2);
                $description = $value[1];
                $value = $value[0];
                include $templatePath . '/row.inc';

                /* Bytes / Request */
                $value = explode(' ', $values[2], 2);
                $description = $value[1];
                $value = $value[0];
                include $templatePath . '/row.inc';
            }
        }

        foreach ($this->_graphs as $graph_id => $graph) {
            include $templatePath . '/row-graph.inc';
        }

        include $templatePath . '/footer.inc';
    }

    function retrieveStoreableData()
    {
        if (!$this->params['status']) {
            return array();
        }

        $data = array();

        $fcontents = @file ('http://' . $this->params['hostspec'] . ':' . $this->params['port'] .'/server-status');
        if (!is_array($fcontents)) {
            return array();
        }

        foreach ($fcontents as $line) {
            if (strstr($line, 'Total accesses')) {
                /* Total Accesses */
                $values = explode(' - ', $line);
                $value = explode(':', $values[0]);
                $data['hits']['value'] = intval($value[1]);
                $data['hits']['data_type'] = NIC_DATA_COUNTER;

                /* Total Traffic */
                $value = explode(':', $values[1]);
                $data['traffic']['value'] = substr($value[1], 0, strpos($value[1], 'M') -1 );
                $data['traffic']['value'] = floatval($data['traffic']['value']) * 1024.0;
                $data['traffic']['data_type'] = NIC_DATA_COUNTER;
            } elseif (strstr($line, 'requests/sec')) {
                /* Requests / Second */
                $values = explode(' - ', $line);
                $value = explode(' ', $values[0]);
                $data['requestpersecond']['value'] = floatval($value[0]);
                $data['requestpersecond']['data_type'] = NIC_DATA_RATE;

                /* Bytes / Second */
                $value = explode(' ', $values[1]);
                $data['bytespersecond']['value'] = floatval($value[0]);
                $data['bytespersecond']['data_type'] = NIC_DATA_RATE;

                /* Bytes / Request */
                $value = explode(' ', $values[2]);
                $data['bytesperrequest']['value'] = floatval($value[0]);
                $data['bytesperrequest']['data_type'] = NIC_DATA_RATE;
            }
        }

        return $data;
    }

}
