<?php

require_once NIC_BASE . '/lib/Device/SNMP.php';

/**
 * Nic_Device_win2k:: Nic_Device implementation to retrieve data from
 * a windows 2000 system running the SNMP service.
 *
 * @author  Mike Cochrane <mike@graftonhall.co.nz>
 * @since   Nic 0.2
 * @package Nic
 */
class Nic_Device_win2k extends Nic_Device_SNMP {

    /* SNMP Object ID's to retrieve */
    var $oids = array(
        array('name' => 'Uptime', 'oid' => '.1.3.6.1.2.1.1.3.0', 'storeable' => false),
        array('name' => 'System Description', 'oid' => '.1.3.6.1.2.1.1.1.0', 'storeable' => false),
        array('name' => 'Active Services Count', 'oid' => '.1.3.6.1.4.1.77.1.2.2.0', 'storeable' => true, 'data_type' => NIC_DATA_GAUGE),
        array('name' => 'Windows File Sharing - Total Bytes sent', 'oid' => '.1.3.6.1.4.1.77.1.2.12.0', 'storeable' => true),
        array('name' => 'Windows File Sharing - Total Bytes recieved', 'oid' => '.1.3.6.1.4.1.77.1.2.13.0', 'storeable' => true),
        array('name' => 'Windows File Sharing - Active Sessions', 'oid' => '.1.3.6.1.4.1.77.1.2.19.0', 'storeable' => true, 'data_type' => NIC_DATA_GAUGE),
        array('name' => 'TCP - Active Opens', 'oid' => 'tcp.tcpActiveOpens.0', 'storeable' => true),
        array('name' => 'TCP - Passive Opens', 'oid' => 'tcp.tcpPassiveOpens.0', 'storeable' => true),
        array('name' => 'TCP - Currently Established', 'oid' => 'tcp.tcpCurrEstab.0', 'storeable' => true, 'data_type' => NIC_DATA_GAUGE),
        array('name' => 'TCP - Out Segments', 'oid' => 'tcp.tcpOutSegs.0', 'storeable' => true),
        array('name' => 'TCP - In Segments', 'oid' => 'tcp.tcpInSegs.0', 'storeable' => true),
        array('name' => 'TCP - Retransmitted Segments', 'oid' => 'tcp.tcpRetransSegs.0', 'storeable' => true),
        array('name' => 'SNMP - In Packets', 'oid' => 'snmp.snmpInPkts.0', 'storeable' => true),
        array('name' => 'SNMP - Out Packets', 'oid' => 'snmp.snmpOutPkts.0', 'storeable' => true),
        array('name' => 'UDP - In Datagrams', 'oid' => 'udp.udpInDatagrams.0', 'storeable' => true),
        array('name' => 'UDP - Out Datagrams', 'oid' => 'udp.udpOutDatagrams.0', 'storeable' => true),
        array('name' => 'ICMP - In Msgs', 'oid' => 'icmp.icmpInMsgs.0', 'storeable' => true),
        array('name' => 'ICMP - Out Msgs', 'oid' => 'icmp.icmpOutMsgs.0', 'storeable' => true),
        array('name' => 'ICMP - In Echo Replies', 'oid' => 'icmp.icmpInEchoReps.0', 'storeable' => true),
        array('name' => 'ICMP - Out Echos', 'oid' => 'icmp.icmpOutEchos.0', 'storeable' => true),
        array('name' => 'ICMP - In Echos', 'oid' => 'icmp.icmpInEchos.0', 'storeable' => true),
        array('name' => 'ICMP - Out Echo Replies', 'oid' => 'icmp.icmpOutEchoReps.0', 'storeable' => true),
    );

    /* Array containing the details of graphs available for this device. */
    var $_graphs = array(
        array(
            'title' => 'Active Services',
            'axisLabel' => 'Number of Services',
            'data' => array(
                array(
                    'source' => 'Active Services Count',
                    'legend' => 'Number of Active Services',
                    'description' => 'The number of active services running on the computer',
                    'type' => NIC_DATA_INTEGER
                )
            ),
        ),
        array(
            'title' => 'Windows File Sharing',
            'axisLabel' => 'KB / Second',
            'data' => array(
                array(
                    'source' => 'Windows File Sharing - Total Bytes sent',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Bytes Sent',
                    'description' => 'The rate at which data is being sent from this server to clients.',
                    'scale_function' => '/',
                    'scale_factor' => 1024,
                ),
                array(
                    'source' => 'Windows File Sharing - Total Bytes recieved',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Bytes Recieved',
                    'description' => 'The rate at which data is being recieved by this server from clients.',
                    'scale_function' => '/',
                    'scale_factor' => 1024,
                )
            ),
        ),
        array(
            'title' => 'Windows File Sharing',
            'axisLabel' => 'Number of Sessions',
            'data' => array(
                array(
                    'source' => 'Windows File Sharing - Active Sessions',
                    'legend' => 'Active Sessions',
                    'description' => 'The number of different users conencted to this computer',
                    'type' => NIC_DATA_INTEGER
                )
            ),
        ),
        array(
            'title' => 'TCP/IP',
            'axisLabel' => 'Segments / Second',
            'data' => array(
                array(
                    'source' => 'TCP - Out Segments',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Segments Sent',
                    'description' => 'The rate at which segments are being sent from this server to clients.',
                ),
                array(
                    'source' => 'TCP - In Segments',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Segments Recieved',
                    'description' => 'The rate at which segments are being recieved by this server from clients.',
                )
            ),
        ),
        array(
            'title' => 'SNMP',
            'axisLabel' => 'Packets / Second',
            'data' => array(
                array(
                    'source' => 'SNMP - Out Packets',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Packets Sent',
                    'description' => 'The rate at which packets are being sent from this server to clients.',
                ),
                array(
                    'source' => 'SNMP - In Packets',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Packets Recieved',
                    'description' => 'The rate at which packets are being recieved by this server from clients.',
                )
            ),
        ),
        array(
            'title' => 'UDP',
            'axisLabel' => 'Datagrams / Second',
            'data' => array(
                array(
                    'source' => 'UDP - Out Datagrams',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Datagrams Sent',
                    'description' => 'The rate at which datagrams are being sent from this server to clients.',
                ),
                array(
                    'source' => 'UDP - In Datagrams',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Datagrams Recieved',
                    'description' => 'The rate at which datagrams are being recieved by this server from clients.',
                )
            ),
        ),
        array(
            'title' => 'ICMP',
            'axisLabel' => 'Messages / Second',
            'data' => array(
                array(
                    'source' => 'ICMP - Out Msgs',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Messages Sent',
                    'description' => 'The rate at which messages are being sent from this server to clients.',
                ),
                array(
                    'source' => 'ICMP - In Msgs',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Messages Recieved',
                    'description' => 'The rate at which messages are being recieved by this server from clients.',
                )
            ),
        ),
    );

    function Nic_Device_win2k($params = array())
    {
        $this->params = $params;
        if (!isset($this->params['timeout'])) {
            $this->params['timeout'] = 10;
        }
    }

    function getStatus()
    {
        $status = array();
        $status['status'] = NIC_STATUS_NORMAL;
        $status['message'] = '';

        $uptime = @snmpget($this->params['hostspec'] . ':' . $this->params['port'], $this->params['community'], '.1.3.6.1.2.1.1.3.0', $this->params['timeout'], 2);

        if ($uptime === false) {
            $status['status'] = NIC_STATUS_FAULT;
        } else {
            $status['message'] = sprintf(_("Uptime: %s"), $this->_cleanResponse($uptime));
        }

        return $status;
    }

}
